Application Development
=======================

To interact with the XBR Network, you need to talk the XBR Network smart contracts
that live on the blockchain.
The contracts and their complete public API are documented in :ref:`XBRAPI`.

Here, we show how to use XBR Lib, a client library we provide for JavaScript and
Python that bundles everything you need for a browser or NodeJS application.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    overview
    requirements
    connecting
    membership
    domains
    markets
    channels
    misc
